Module job

Module job 

Retrieve jobs

Structs

HealthIter
An iterator over the variants of Health
Job
The data available for a job from the LAVA API
Jobs
A Stream that yields a selected subset of the Job instances on a LAVA server.
JobsBuilder
Select a set of Job instances to return from the LAVA server.
StateIter
An iterator over the variants of State

Enums

CancellationError
Health
The completion state of a job.
Ordering
The possible orderings in which jobs can be returned
ResultsError
State
The progress of a job through the system.
SubmissionError

Functions

cancel_job
job_results_as_junit
submit_job