pub enum Health {
Unknown,
Complete,
Incomplete,
Canceled,
}Expand description
The completion state of a job.
Variants
Unknown
Unknown is the usual state before the job has finished.
Complete
Complete is used as the success state in general.
Incomplete
Incomplete is used as the error state.
Canceled